from ..Material.Material import Material
from ..Model.ModelBase import ModelBase


class MaterialModel(ModelBase):
    """Abaqus creates a Model object named `Model-1` when a session is started.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            mdb.models[name]
    """

    def Material(self, name: str, description: str = "", materialIdentifier: str = ""):
        """This method creates a Material object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].Material

        Parameters
        ----------
        name
            A String specifying the name of the new material.
        description
            A String specifying user description of the material. The default value is an empty
            string.
        materialIdentifier
            A String specifying material identifier for customer use. The default value is an empty
            string.

        Returns
        -------
        Material
            A :py:class:`~abaqus.Material.Material.Material` object.
        """
        self.materials[name] = material = Material(
            name, description, materialIdentifier
        )
        return material



from abaqusConstants import *
from .BrittleFailure import BrittleFailure
from .BrittleShear import BrittleShear


class BrittleCracking:
    """The BrittleCracking object specifies cracking and postcracking properties for the
    brittle cracking material model.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import material
            mdb.models[name].materials[name].brittleCracking
            import odbMaterial
            session.odbs[name].materials[name].brittleCracking

        The table data for this object are:

        - If **type** = STRAIN the table data specify the following:
        
            - Remaining direct stress after cracking.
            - Direct cracking strain.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If **type** = DISPLACEMENT the table data specify the following:
        
            - Remaining direct stress after cracking.
            - Direct cracking displacement.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If **type** = GFI the table data specify the following:
        
            - Failure stress.
            - Mode I fracture energy.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.

        The corresponding analysis keywords are:

        - BRITTLE CRACKING
    """

    #: A :py:class:`~abaqus.Material.Plastic.Concrete.BrittleShear.BrittleShear` object.
    brittleShear: BrittleShear = BrittleShear(((),))

    #: A :py:class:`~abaqus.Material.Plastic.Concrete.BrittleFailure.BrittleFailure` object.
    brittleFailure: BrittleFailure = BrittleFailure(((),))

    def __init__(
        self,
        table: tuple,
        temperatureDependency: Boolean = OFF,
        dependencies: int = 0,
        type: SymbolicConstant = STRAIN,
    ):
        """This method creates a BrittleCracking object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].materials[name].BrittleCracking
                session.odbs[name].materials[name].BrittleCracking

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described below.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.
        type
            A SymbolicConstant specifying the type of postcracking behavior. Possible values are
            STRAIN, DISPLACEMENT, and GFI. The default value is STRAIN.

        Returns
        -------
        BrittleCracking
            A :py:class:`~abaqus.Material.Plastic.Concrete.BrittleCracking.BrittleCracking` object.
        """
        pass

    def setValues(self, *args, **kwargs):
        """This method modifies the BrittleCracking object."""
        pass



class VelocityDependence:
    r"""The VelocityDependence object specifies the dependence of the permeability of a material
    on the velocity of fluid flow.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import material
            mdb.models[name].materials[name].permeability.velocityDependence
            import odbMaterial
            session.odbs[name].materials[name].permeability.velocityDependence

        The table data for this object are:

        - :math:`\beta`. Only :math:`\beta>0.0` is allowed.
        - Void ratio, :math:`e`.

        The corresponding analysis keywords are:

        - PERMEABILITY
    """

    def __init__(self, table: tuple):
        """This method creates a VelocityDependence object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].materials[name].permeability.VelocityDependence
                session.odbs[name].materials[name].permeability.VelocityDependence

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described below.

        Returns
        -------
        VelocityDependence
            A :py:class:`~abaqus.Material.Others.PoreFluidFlow.Permeability.VelocityDependence.VelocityDependence` object.

        Raises
        ------
        RangeError
        """
        pass

    def setValues(self, *args, **kwargs):
        """This method modifies the VelocityDependence object.

        Raises
        ------
        RangeError
        """
        pass



from abaqusConstants import *
from .Leaf import Leaf


class LeafFromPartInstance(Leaf):
    """The LeafFromPartInstance object can be used whenever a Leaf object is expected as an
    argument. Leaf objects are used to specify the items in a display group. Leaf objects
    are constructed as temporary objects, which are then used as arguments to DisplayGroup
    commands.
    The LeafFromPartInstance object is derived from the Leaf object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import displayGroupOdbToolset
    """

    #: A SymbolicConstant specifying the leaf type. Possible values are EMPTY_LEAF,
    #: DEFAULT_MODEL, ALL_ELEMENTS, ALL_NODES, and ALL_SURFACES.
    leafType: SymbolicConstant = None

    #: A sequence of Strings specifying the names of the part instances.
    partInstanceName: tuple

    def __init__(self, partInstanceName: tuple):
        """This method creates a Leaf object from a list of part instance names.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                LeafFromPartInstance

        Parameters
        ----------
        partInstanceName
            A sequence of Strings specifying the names of the part instances.

        Returns
        -------
        LeafFromPartInstance
            A :py:class:`~abaqus.DisplayGroup.LeafFromPartInstance.LeafFromPartInstance` object.
        """
        super().__init__(DEFAULT_MODEL)
        pass



class AbaqusBoolean:
    """The AbaqusBoolean object is used in a similar way to the SymbolicConstant object. If you
    pass an AbaqusBoolean object to the Python repr() function, the function returns the
    text without quotes. In effect, the text is the variable that, by convention, refers to
    the AbaqusBoolean object.
    An :py:class:`~abaqus.UtilityAndView.AbaqusBoolean.AbaqusBoolean` object has a value of 0 or 1, and an AbaqusBoolean object can be tested
    in an if statement. You can use an AbaqusBoolean object as an argument to a method in
    place of 1 or 0. Conversely, you can pass a 0 or a 1 to an Abaqus Scripting Interface
    method that expects a Boolean argument, and the 0 or 1 will be coerced to the
    appropriate AbaqusBoolean value.
    There are only two possible values for an AbaqusBoolean object: 1 and 0. You can import
    both values from the symbolicConstants module or from the abaqus module. Abaqus
    Scripting Interface commands that expect an AbaqusBoolean object will also accept a
    Python bool (True, False), or a Python int (1, 0).

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            from symbolicConstants import *
            from abaqusConstants import *
    """

    def __init__(self, value: int):
        """The AbaqusBoolean method creates an AbaqusBoolean object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                AbaqusBoolean

        Parameters
        ----------
        value
            An Int specifying whether the AbaqusBoolean object will test true or false. Possible
            values are 0 and 1, which will create the AbaqusBoolean method OFF and ON, respectively.

        Returns
        -------
        AbaqusBoolean
            An :py:class:`~abaqus.UtilityAndView.AbaqusBoolean.AbaqusBoolean` object.
        """
        pass



from abaqusConstants import *


class SvgOptions:
    """The SvgOptions object stores the settings that Abaqus uses when printing in SVG format.
    The SvgOptions object has no constructor. Abaqus creates the **svgOptions** member when a
    session is started.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            session.svgOptions
    """

    def setValues(self, imageSize: SymbolicConstant = SIZE_ON_SCREEN):
        """This method modifies the SvgOptions object.

        Parameters
        ----------
        imageSize
            The SymbolicConstant SIZE_ON_SCREEN or a pair of Ints specifying the width and height of
            the image in pixels. Possible values are (*minWidth*, **minHeight** ) ≤≤ **imageSize** ≤≤
            (*maxWidth* and **maxHeight**). The default value is SIZE_ON_SCREEN.Note:The minimum value
            of width and height (*minWidth* and **minHeight**) is the number of pixels that occupy 10
            mm at the current screen resolution. The value is typically around 50 pixels and may be
            different for width and height.The maximum value of width and height (*maxWidth* and
            **maxHeight**) is the largest number of pixels supported by the system graphics and will
            be at least as large as the screen dimensions.

        Raises
        ------
        RangeError
            - If either the width or height arguments of **imageSize** are out of range (where
            **minWidth** and **minHeight** are the number of pixels corresponding to approximately 10 mm
            for a given display and **maxWidth** and **maxHeight** are the largest allowable number of
            pixels supported by the system graphics):
              RangeError: imageSize must be SIZE_ON_SCREEN or a sequence of 2 Ints in the range
            (minWidth, minHeight) <= (width, height) <= (maxWidth, maxHeight).
        """
        pass



from .Section import Section


class AcousticInterfaceSection(Section):
    """The AcousticInterfaceSection object defines the properties of an acoustic section.
    The AcousticInterfaceSection object is derived from the Section object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import section
            mdb.models[name].sections[name]
            import odbSection
            session.odbs[name].sections[name]

        The corresponding analysis keywords are:

        - INTERFACE
    """

    #: A String specifying the repository key.
    name: str

    #: A Float specifying the thickness of the section. Possible values are **thickness** >> 0.0.
    #: The default value is 1.0.
    thickness: float = 1

    def __init__(self, name: str, thickness: float = 1):
        """This method creates an AcousticInterfaceSection object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].AcousticInterfaceSection
                session.odbs[name].AcousticInterfaceSection

        Parameters
        ----------
        name
            A String specifying the repository key.
        thickness
            A Float specifying the thickness of the section. Possible values are **thickness** >> 0.0.
            The default value is 1.0.

        Returns
        -------
        AcousticInterfaceSection
            An :py:class:`~abaqus.Section.AcousticInterfaceSection.AcousticInterfaceSection` object.

        Raises
        ------
        InvalidNameError
        RangeError
        """
        super().__init__()
        pass

    def setValues(self, thickness: float = 1):
        """This method modifies the AcousticInterfaceSection object.

        Parameters
        ----------
        thickness
            A Float specifying the thickness of the section. Possible values are **thickness** >> 0.0.
            The default value is 1.0.

        Raises
        ------
        RangeError
        """
        pass



from abaqusConstants import *
from .BoundaryCondition import BoundaryCondition
from ..Region.Region import Region


class TypeBC(BoundaryCondition):
    """The TypeBC object stores the data for several types of predefined boundary conditions
    that are commonly used in stress/displacement analyses.
    The TypeBC object is derived from the BoundaryCondition object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import load
            mdb.models[name].boundaryConditions[name]
    """

    #: A String specifying the boundary condition repository key.
    name: str = ""

    #: A SymbolicConstant specifying how the boundary condition is defined in a BUCKLE
    #: analysis. Possible values are NOT_APPLICABLE, STRESS_PERTURBATION, BUCKLING_MODES, and
    #: PERTURBATION_AND_BUCKLING. The default value is NOT_APPLICABLE.
    buckleCase: SymbolicConstant = NOT_APPLICABLE

    #: A SymbolicConstant specifying the category of the boundary condition. Possible values
    #: are MECHANICAL and THERMAL.
    category: SymbolicConstant = None

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the boundary condition is applied.
    region: Region = Region()

    #: None or a DatumCsys object specifying the local coordinate system of the boundary
    #: condition's degrees of freedom. If **localCsys** = None, the degrees of freedom are defined
    #: in the global coordinate system. The default value is None.
    localCsys: str = None

    def __init__(
        self,
        name: str,
        createStepName: str,
        region: Region,
        buckleCase: SymbolicConstant = NOT_APPLICABLE,
        localCsys: str = None,
    ) -> None:
        """This method creates an TypeBC object.
        
        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].EncastreBC
                mdb.models[name].PinnedBC
                mdb.models[name].XsymmBC
                mdb.models[name].YsymmBC
                mdb.models[name].ZsymmBC
                mdb.models[name].XasymmBC
                mdb.models[name].YasymmBC
                mdb.models[name].ZasymmBC

        Parameters
        ----------
        name
            A String specifying the boundary condition repository key.
        createStepName
            A String specifying the name of the step in which the boundary condition is created.
        region
            A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the boundary condition is applied.
        buckleCase
            A SymbolicConstant specifying how the boundary condition is defined in a BUCKLE
            analysis. Possible values are NOT_APPLICABLE, STRESS_PERTURBATION, BUCKLING_MODES, and
            PERTURBATION_AND_BUCKLING. The default value is NOT_APPLICABLE.
        localCsys
            None or a DatumCsys object specifying the local coordinate system of the boundary
            condition's degrees of freedom. If **localCsys** = None, the degrees of freedom are defined
            in the global coordinate system. The default value is None.
        """
        super().__init__()
        self.name = name
        self.buckleCase = buckleCase
        self.region = region
        self.localCsys = localCsys

    @staticmethod
    def EncastreBC(
        name: str,
        createStepName: str,
        region: Region,
        buckleCase: SymbolicConstant = NOT_APPLICABLE,
        localCsys: str = None,
    ) -> "TypeBC":
        """This method creates an encastre TypeBC object.
        
        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].EncastreBC

        Parameters
        ----------
        name
            A String specifying the boundary condition repository key.
        createStepName
            A String specifying the name of the step in which the boundary condition is created.
        region
            A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the boundary condition is applied.
        buckleCase
            A SymbolicConstant specifying how the boundary condition is defined in a BUCKLE
            analysis. Possible values are NOT_APPLICABLE, STRESS_PERTURBATION, BUCKLING_MODES, and
            PERTURBATION_AND_BUCKLING. The default value is NOT_APPLICABLE.
        localCsys
            None or a DatumCsys object specifying the local coordinate system of the boundary
            condition's degrees of freedom. If **localCsys** = None, the degrees of freedom are defined
            in the global coordinate system. The default value is None.

        Returns
        -------
        TypeBC
            A :py:class:`~abaqus.BoundaryCondition.TypeBC.TypeBC` object.
        """
        return TypeBC(name, createStepName, region, buckleCase, localCsys)

    @staticmethod
    def PinnedBC(
        name: str,
        createStepName: str,
        region: Region,
        buckleCase: SymbolicConstant = NOT_APPLICABLE,
        localCsys: str = None,
    ) -> "TypeBC":
        """This method creates a pinned TypeBC object.
        
        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].PinnedBC

        Parameters
        ----------
        name
            A String specifying the boundary condition repository key.
        createStepName
            A String specifying the name of the step in which the boundary condition is created.
        region
            A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the boundary condition is applied.
        buckleCase
            A SymbolicConstant specifying how the boundary condition is defined in a BUCKLE
            analysis. Possible values are NOT_APPLICABLE, STRESS_PERTURBATION, BUCKLING_MODES, and
            PERTURBATION_AND_BUCKLING. The default value is NOT_APPLICABLE.
        localCsys
            None or a DatumCsys object specifying the local coordinate system of the boundary
            condition's degrees of freedom. If **localCsys** = None, the degrees of freedom are defined
            in the global coordinate system. The default value is None.

        Returns
        -------
        TypeBC
            A :py:class:`~abaqus.BoundaryCondition.TypeBC.TypeBC` object.
        """
        return TypeBC(name, createStepName, region, buckleCase, localCsys)

    @staticmethod
    def XsymmBC(
        name: str,
        createStepName: str,
        region: Region,
        buckleCase: SymbolicConstant = NOT_APPLICABLE,
        localCsys: str = None,
    ) -> "TypeBC":
        """This method creates a TypeBC object that specifies symmetry about the **X**-axis.
        
        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].XsymmBC

        Parameters
        ----------
        name
            A String specifying the boundary condition repository key.
        createStepName
            A String specifying the name of the step in which the boundary condition is created.
        region
            A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the boundary condition is applied.
        buckleCase
            A SymbolicConstant specifying how the boundary condition is defined in a BUCKLE
            analysis. Possible values are NOT_APPLICABLE, STRESS_PERTURBATION, BUCKLING_MODES, and
            PERTURBATION_AND_BUCKLING. The default value is NOT_APPLICABLE.
        localCsys
            None or a DatumCsys object specifying the local coordinate system of the boundary
            condition's degrees of freedom. If **localCsys** = None, the degrees of freedom are defined
            in the global coordinate system. The default value is None.

        Returns
        -------
        TypeBC
            A :py:class:`~abaqus.BoundaryCondition.TypeBC.TypeBC` object.
        """
        return TypeBC(name, createStepName, region, buckleCase, localCsys)

    @staticmethod
    def YsymmBC(
        name: str,
        createStepName: str,
        region: Region,
        buckleCase: SymbolicConstant = NOT_APPLICABLE,
        localCsys: str = None,
    ) -> "TypeBC":
        """This method creates a TypeBC object that specifies symmetry about the **Y**-axis.
        
        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].YsymmBC

        Parameters
        ----------
        name
            A String specifying the boundary condition repository key.
        createStepName
            A String specifying the name of the step in which the boundary condition is created.
        region
            A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the boundary condition is applied.
        buckleCase
            A SymbolicConstant specifying how the boundary condition is defined in a BUCKLE
            analysis. Possible values are NOT_APPLICABLE, STRESS_PERTURBATION, BUCKLING_MODES, and
            PERTURBATION_AND_BUCKLING. The default value is NOT_APPLICABLE.
        localCsys
            None or a DatumCsys object specifying the local coordinate system of the boundary
            condition's degrees of freedom. If **localCsys** = None, the degrees of freedom are defined
            in the global coordinate system. The default value is None.

        Returns
        -------
        TypeBC
            A :py:class:`~abaqus.BoundaryCondition.TypeBC.TypeBC` object.
        """
        return TypeBC(name, createStepName, region, buckleCase, localCsys)

    @staticmethod
    def ZsymmBC(
        name: str,
        createStepName: str,
        region: Region,
        buckleCase: SymbolicConstant = NOT_APPLICABLE,
        localCsys: str = None,
    ) -> "TypeBC":
        """This method creates a TypeBC object that specifies symmetry about the **Z**-axis.
        
        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].ZsymmBC

        Parameters
        ----------
        name
            A String specifying the boundary condition repository key.
        createStepName
            A String specifying the name of the step in which the boundary condition is created.
        region
            A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the boundary condition is applied.
        buckleCase
            A SymbolicConstant specifying how the boundary condition is defined in a BUCKLE
            analysis. Possible values are NOT_APPLICABLE, STRESS_PERTURBATION, BUCKLING_MODES, and
            PERTURBATION_AND_BUCKLING. The default value is NOT_APPLICABLE.
        localCsys
            None or a DatumCsys object specifying the local coordinate system of the boundary
            condition's degrees of freedom. If **localCsys** = None, the degrees of freedom are defined
            in the global coordinate system. The default value is None.

        Returns
        -------
        TypeBC
            A :py:class:`~abaqus.BoundaryCondition.TypeBC.TypeBC` object.
        """
        return TypeBC(name, createStepName, region, buckleCase, localCsys)

    @staticmethod
    def XasymmBC(
        name: str,
        createStepName: str,
        region: Region,
        buckleCase: SymbolicConstant = NOT_APPLICABLE,
        localCsys: str = None,
    ) -> "TypeBC":
        """This method creates a TypeBC object that specifies antisymmetry about the **X**-axis.
        
        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].XasymmBC

        Parameters
        ----------
        name
            A String specifying the boundary condition repository key.
        createStepName
            A String specifying the name of the step in which the boundary condition is created.
        region
            A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the boundary condition is applied.
        buckleCase
            A SymbolicConstant specifying how the boundary condition is defined in a BUCKLE
            analysis. Possible values are NOT_APPLICABLE, STRESS_PERTURBATION, BUCKLING_MODES, and
            PERTURBATION_AND_BUCKLING. The default value is NOT_APPLICABLE.
        localCsys
            None or a DatumCsys object specifying the local coordinate system of the boundary
            condition's degrees of freedom. If **localCsys** = None, the degrees of freedom are defined
            in the global coordinate system. The default value is None.

        Returns
        -------
        TypeBC
            A :py:class:`~abaqus.BoundaryCondition.TypeBC.TypeBC` object.
        """
        return TypeBC(name, createStepName, region, buckleCase, localCsys)

    @staticmethod
    def YasymmBC(
        name: str,
        createStepName: str,
        region: Region,
        buckleCase: SymbolicConstant = NOT_APPLICABLE,
        localCsys: str = None,
    ) -> "TypeBC":
        """This method creates a TypeBC object that specifies antisymmetry about the **Y**-axis.
        
        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].YasymmBC

        Parameters
        ----------
        name
            A String specifying the boundary condition repository key.
        createStepName
            A String specifying the name of the step in which the boundary condition is created.
        region
            A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the boundary condition is applied.
        buckleCase
            A SymbolicConstant specifying how the boundary condition is defined in a BUCKLE
            analysis. Possible values are NOT_APPLICABLE, STRESS_PERTURBATION, BUCKLING_MODES, and
            PERTURBATION_AND_BUCKLING. The default value is NOT_APPLICABLE.
        localCsys
            None or a DatumCsys object specifying the local coordinate system of the boundary
            condition's degrees of freedom. If **localCsys** = None, the degrees of freedom are defined
            in the global coordinate system. The default value is None.

        Returns
        -------
        TypeBC
            A :py:class:`~abaqus.BoundaryCondition.TypeBC.TypeBC` object.
        """
        return TypeBC(name, createStepName, region, buckleCase, localCsys)

    @staticmethod
    def ZasymmBC(
        name: str,
        createStepName: str,
        region: Region,
        buckleCase: SymbolicConstant = NOT_APPLICABLE,
        localCsys: str = None,
    ) -> "TypeBC":
        """This method creates a TypeBC object that specifies antisymmetry about the **Z**-axis.
        
        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].ZasymmBC

        Parameters
        ----------
        name
            A String specifying the boundary condition repository key.
        createStepName
            A String specifying the name of the step in which the boundary condition is created.
        region
            A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the boundary condition is applied.
        buckleCase
            A SymbolicConstant specifying how the boundary condition is defined in a BUCKLE
            analysis. Possible values are NOT_APPLICABLE, STRESS_PERTURBATION, BUCKLING_MODES, and
            PERTURBATION_AND_BUCKLING. The default value is NOT_APPLICABLE.
        localCsys
            None or a DatumCsys object specifying the local coordinate system of the boundary
            condition's degrees of freedom. If **localCsys** = None, the degrees of freedom are defined
            in the global coordinate system. The default value is None.

        Returns
        -------
        TypeBC
            A :py:class:`~abaqus.BoundaryCondition.TypeBC.TypeBC` object.
        """
        return TypeBC(name, createStepName, region, buckleCase, localCsys)

    def setValues(
        self,
        region: Region,
        typeName: SymbolicConstant = None,
        buckleCase: SymbolicConstant = NOT_APPLICABLE,
        localCsys: str = None,
    ):
        """This method modifies the data for an existing TypeBC object in the step where it is
        created.
        
        Parameters
        ----------
        region
            A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the boundary condition is applied.
        typeName
            A SymbolicConstant specifying the predefined boundary condition type. Possible values
            are XSYMM, YSYMM, ZSYMM, XASYMM, YASYMM, ZASYMM, PINNED, and ENCASTRE.
        buckleCase
            A SymbolicConstant specifying how the boundary condition is defined in a BUCKLE
            analysis. Possible values are NOT_APPLICABLE, STRESS_PERTURBATION, BUCKLING_MODES, and
            PERTURBATION_AND_BUCKLING. The default value is NOT_APPLICABLE.
        localCsys
            None or a DatumCsys object specifying the local coordinate system of the boundary
            condition's degrees of freedom. If **localCsys** = None, the degrees of freedom are defined
            in the global coordinate system. The default value is None.
        """
        pass

    def setValuesInStep(self, stepName: str, typeName: SymbolicConstant = None):
        """This method always returns a value error for a TypeBC; it is inherited from the
        BoundaryCondition object.

        Parameters
        ----------
        stepName
            A String specifying the name of the step in which the boundary condition is modified.
        typeName
            A SymbolicConstant specifying the predefined boundary condition type. Possible values
            are XSYMM, YSYMM, ZSYMM, XASYMM, YASYMM, ZASYMM, PINNED, and ENCASTRE.

        Raises
        ------
        Value Error
            A Symmetry/Antisymmetry/Encastre BC cannot be edited in a propagated step.
        """
        pass



class OdbJobTime:
    """The OdbJobTime object stores the analysis time of a job.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import visualization
            session.odbData[name].diagnosticData.jobTime
    """

    #: A float specifying the systemtime for the analysis. This attribute is read-only.
    systemTime: str = ""

    #: A float specifying the usertime for the analysis. This attribute is read-only.
    userTime: str = ""

    #: A float specifying the wallclocktime for the analysis. This attribute is read-only.
    wallclockTime: str = ""



from abaqusConstants import *


class RateDependent:
    r"""The RateDependent object defines a rate-dependent viscoplastic model.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import material
            mdb.models[name].materials[name].crushableFoam.rateDependent
            mdb.models[name].materials[name].druckerPrager.rateDependent
            mdb.models[name].materials[name].Plastic.rateDependent
            import odbMaterial
            session.odbs[name].materials[name].crushableFoam.rateDependent
            session.odbs[name].materials[name].druckerPrager.rateDependent
            session.odbs[name].materials[name].Plastic.rateDependent

        The table data for this object are:

        - If **type** = POWER_LAW, the table data specify the following:
        
            - :math:`D`.
            - :math:`n`.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If **type** = YIELD_RATIO, the table data specify the following:
        
            - Yield stress ratio, :math:`R=\bar{\sigma} / \sigma^{0}`.
            - Equivalent plastic strain rate, :math:`\dot{\bar{\varepsilon}}^{p l}`.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If **type** = JOHNSON_COOK, the table data specify the following:

            - :math:`C`.
            - :math:`\dot{\varepsilon}_{0}`.

        The corresponding analysis keywords are:

        - RATE DEPENDENT
    """

    def __init__(
        self,
        table: tuple,
        type: SymbolicConstant = POWER_LAW,
        temperatureDependency: Boolean = OFF,
        dependencies: int = 0,
    ):
        """This method creates a RateDependent object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].materials[name].crushableFoam.RateDependent
                mdb.models[name].materials[name].druckerPrager.RateDependent
                mdb.models[name].materials[name].Plastic.RateDependent
                session.odbs[name].materials[name].crushableFoam.RateDependent
                session.odbs[name].materials[name].druckerPrager.RateDependent
                session.odbs[name].materials[name].Plastic.RateDependent

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described below.
        type
            A SymbolicConstant specifying the type of rate-dependent data. Possible values are
            POWER_LAW, YIELD_RATIO, and JOHNSON_COOK. The default value is POWER_LAW.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.

        Returns
        -------
        RateDependent
            A :py:class:`~abaqus.Material.Plastic.Metal.RateDependent.RateDependent.RateDependent` object.

        Raises
        ------
        RangeError
        """
        pass

    def setValues(self, *args, **kwargs):
        """This method modifies the RateDependent object.

        Raises
        ------
        RangeError
        """
        pass



class Gel:
    r"""The Gel object defines a swelling gel.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import material
            mdb.models[name].materials[name].gel
            import odbMaterial
            session.odbs[name].materials[name].gel

        The table data for this object are:

        - Radius of gel particles when completely dry, :math:`r_{a}^{\mathrm{dry}}`.
        - Fully swollen radius of gel particles, :math:`r_{a}^{f}`.
        - Number of gel particles per unit volume, :math:`k_{a}`.
        - Relaxation time constant for long-term swelling of gel particles, :math:`\tau_{1}`.

        The corresponding analysis keywords are:

        - GEL
    """

    def __init__(self, table: tuple):
        """This method creates a Gel object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].materials[name].Gel
                session.odbs[name].materials[name].Gel

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described below.

        Returns
        -------
        Gel
            A :py:class:`~abaqus.Material.Others.PoreFluidFlow.Gel.Gel` object.
        """
        pass

    def setValues(self, *args, **kwargs):
        """This method modifies the Gel object."""
        pass



from abaqusConstants import *
from .PartInstance import PartInstance

# from ..Model.ModelBase import ModelBase


# Prevent circular import
class ModelBase:
    pass


class AssemblyModel(ModelBase):
    """Abaqus creates a Model object named `Model-1` when a session is started.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            mdb.models[name]
    """

    def Instance(self, name: str, objectToCopy: PartInstance):
        """This method copies a PartInstance object from the specified model and creates a new
        PartInstance object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].Instance

        Parameters
        ----------
        name
            A String specifying the repository key.
        objectToCopy
            A :py:class:`~abaqus.Assembly.PartInstance.PartInstance` object to be copied.

        Returns
        -------
        Model
            A :py:class:`~abaqus.Model.Model.Model` object.
        """
        return self

    def convertAllSketches(
        self, regenerate: Boolean = True, convertReversedSketches: Boolean = True
    ):
        """This method converts all sketches from Abaqus 6.5 or earlier to the equivalent
        ConstrainedSketch objects.

        Parameters
        ----------
        regenerate
            A Boolean specifying if all the features in assembly as well as in all the parts in the
            model should be regenerated after the conversion. The default value is True.
        convertReversedSketches
            A Boolean specifying whether sketches in analytic rigid parts should be converted even
            if they cause the orientation of surfaces defined on them to be flipped. The default
            value is True.

        Returns
        -------
        list[str]
            A list of strings describing any warnings or errors encountered during the conversion
            process.
        """
        pass

    def linkInstances(self, instancesMap: tuple):
        """This method links the selected PartInstance objects to the corresponding PartInstance
        objects from the specified models. If all instances of a Part are selected for linking,
        the Part will be linked as well. If not, a new linked child Part object will be created
        and added to the repository.

        Parameters
        ----------
        instancesMap
            A tuple of tuples containing the instance name to be linked and the corresponding
            PartInstance object to which it will be linked.

        Returns
        -------
        list[str]
            A list of strings describing any warnings or errors encountered during the conversion
            process.
        """
        pass



from abaqusConstants import *
from .ConnectorBehaviorOption import ConnectorBehaviorOption
from .ConnectorOptions import ConnectorOptions
from .ConnectorPotentialArray import ConnectorPotentialArray
from .DerivedComponent import DerivedComponent
from .TangentialBehavior import TangentialBehavior


class ConnectorFriction(ConnectorBehaviorOption):
    """The ConnectorFriction object defines Coulomb-like or hysteretic friction behavior for
    one or more components of a connector's relative motion.
    The ConnectorFriction object is derived from the ConnectorBehaviorOption object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import section
            mdb.models[name].sections[name].behaviorOptions[i]
            import odbSection
            session.odbs[name].sections[name].behaviorOptions[i]

        The corresponding analysis keywords are:

        - CONNECTOR FRICTION
    """

    #: A :py:class:`~abaqus.Connector.TangentialBehavior.TangentialBehavior` object.
    tangentialBehavior: TangentialBehavior = TangentialBehavior()

    #: A :py:class:`~abaqus.Connector.ConnectorBehaviorOption.DerivedComponent` object specifying the DerivedComponent used to compute the contact
    #: force component direction. This argument applies only if
    #: **frictionModel** = USER_CUSTOMIZED, if **useContactForceComponent** = ON, and if
    #: **contactForceStyle** = DERIVED_COMPONENT.
    derivedComponent: DerivedComponent = DerivedComponent()

    #: A :py:class:`~abaqus.Connector.ConnectorOptions.ConnectorOptions` object specifying the ConnectorOptions used to define tabular options
    #: for this ConnectorBehaviorOption.
    options: ConnectorOptions = ConnectorOptions()

    #: A SymbolicConstant specifying the desired frictional response model. Possible values are
    #: PREDEFINED and USER_CUSTOMIZED. The default value is PREDEFINED.
    frictionModel: SymbolicConstant = PREDEFINED

    #: A SymbolicConstant specifying the method of indicating the slip direction: either
    #: specified or computed based upon the force potential data. Possible values are SPECIFY
    #: and COMPUTE. The default value is SPECIFY.This argument is applicable only if
    #: **frictionModel** = USER_CUSTOMIZED.
    slipStyle: SymbolicConstant = SPECIFY

    #: None or an Int specifying the direction for which the frictional behavior is specified.
    #: Possible values are 1 ≤≤ **tangentDirection** ≤≤ 6, indicating an available component of
    #: relative motion. This argument applies only if **frictionModel** = USER_CUSTOMIZED and if
    #: **slipStyle** = SPECIFY. The default value is None.
    tangentDirection: int = None

    #: None or a Float specifying the stick stiffness associated with the frictional behavior
    #: in the direction specified by **tangentDirection**. If this argument is omitted, Abaqus
    #: computes an appropriate number for the stick stiffness. The default value is None.
    stickStiffness: float = None

    #: A SymbolicConstant specifying the type of the **independentComponents**. Possible values
    #: are POSITION, MOTION, and NO_INDEPENDENT_COMPONENTS. The default value is
    #: NO_INDEPENDENT_COMPONENTS.
    componentType: SymbolicConstant = NO_INDEPENDENT_COMPONENTS

    #: A Boolean specifying whether the table data depend on accumulated slip. The default
    #: value is OFF.This argument applies only if **frictionModel** = USER_CUSTOMIZED.
    slipDependency: Boolean = OFF

    #: A Boolean specifying whether the table data depend on temperature. The default value is
    #: OFF.This argument applies only if **frictionModel** = USER_CUSTOMIZED.
    temperatureDependency: Boolean = OFF

    #: An Int specifying the number of field variable dependencies. The default value is 0.This
    #: argument applies only if **frictionModel** = USER_CUSTOMIZED.
    dependencies: int = 0

    #: A Boolean specifying whether the contact force component will be defined. The default
    #: value is OFF.This argument applies only if **frictionModel** = USER_CUSTOMIZED.
    useContactForceComponent: Boolean = OFF

    #: A SymbolicConstant specifying the method of indicating the contact force component
    #: direction: either specified or computed based on upon a DerivedComponent. Possible
    #: values are COMPONENT_NUMBER and DERIVED_COMPONENT. The default value is
    #: COMPONENT_NUMBER.This argument is applicable only if **frictionModel** = USER_CUSTOMIZED and
    #: if **useContactForceComponent** = ON.
    contactForceStyle: SymbolicConstant = COMPONENT_NUMBER

    #: An Int specifying the contact force component direction. This argument applies only if
    #: **frictionModel** = USER_CUSTOMIZED, if **useContactForceComponent** = ON, and if
    #: **contactForceStyle** = COMPONENT_NUMBER. The default value is 0.
    contactForceComponent: int = 0

    #: A SymbolicConstant specifying the contribution operator for the force potential
    #: contributions. Possible values are SUM and MAXIMUM. The default value is SUM.This
    #: argument is applicable only if **frictionModel** = USER_CUSTOMIZED and if
    #: **slipStyle** = COMPUTE.
    forcePotentialOperator: SymbolicConstant = SUM

    #: A Float specifying the number equal to the inverse of the overall exponent in the force
    #: potential definition. The default value is 2.0.This argument is applicable only if
    #: **frictionModel** = USER_CUSTOMIZED, if **slipStyle** = COMPUTE, and if
    #: **forcePotentialOperator** = SUM.
    forcePotentialExponent: float = 2

    #: A :py:class:`~abaqus.Connector.ConnectorPotentialArray.ConnectorPotentialArray` object specifying one ConnectorPotential object for each force
    #: potential contribution. This member can be specified only if
    #: **frictionModel** = USER_CUSTOMIZED, and if **slipStyle** = COMPUTE.
    connectorPotentials: ConnectorPotentialArray = None

    #: A sequence of sequences of Floats specifying friction properties. The default value is
    #: an empty sequence.If **frictionModel** = PREDEFINED, each sequence of the table data
    #: specifies:If applicable, the first geometric scaling constant relevant to frictional
    #: interactions.Etc., up to as many geometric scaling constants as are associated with this
    #: connection type.Internal contact force/moment generating friction in the first
    #: predefined slip direction.If applicable, internal contact force/moment generating
    #: friction in the second predefined slip direction.Connector constitutive relative motion
    #: in the direction specified by **independentComponent**.Accumulated slip in the first
    #: predefined slip direction, if the data depend on accumulated slip.Temperature, if the
    #: data depend on temperature.Value of the first field variable, if the data depend on
    #: field variables.Value of the second field variable.Etc.If
    #: **frictionModel** = USER_CUSTOMIZED, each sequence of the table data specifies:Effective
    #: radius of the cylindrical or spherical surface over which frictional slip occurs in the
    #: connector associated with frictional effects in the direction specified by
    #: **tangentDirection**. This radius is relevant only if the connection type includes an
    #: available rotational component of relative motion and
    #: **tangentDirection** = SLIP_DIRECTION.Internal contact force/moment generating friction in
    #: the direction specified by **tangentDirection**.Connector constitutive relative motion in
    #: the direction specified by **independentComponent**.Accumulated slip in the direction
    #: specified by **tangentDirection**, if the data depend on accumulated slip.Temperature, if
    #: the data depend on temperature.Value of the first field variable, if the data depend on
    #: field variables.Value of the second field variable.Etc.
    table: tuple = ()

    #: A sequence of Ints specifying the independent components. Possible values are 1 ≤≤
    #: **independentComponents** ≤≤ 6. In addition, each independent component value must be
    #: unique. The **independentComponents** argument applies only if
    #: **frictionModel** = USER_CUSTOMIZED. Only available components can be specified. The default
    #: value is an empty sequence.
    independentComponents: tuple = ()

    def __init__(
        self,
        frictionModel: SymbolicConstant = PREDEFINED,
        slipStyle: SymbolicConstant = SPECIFY,
        tangentDirection: int = None,
        stickStiffness: float = None,
        componentType: SymbolicConstant = NO_INDEPENDENT_COMPONENTS,
        slipDependency: Boolean = OFF,
        temperatureDependency: Boolean = OFF,
        dependencies: int = 0,
        useContactForceComponent: Boolean = OFF,
        contactForceStyle: SymbolicConstant = COMPONENT_NUMBER,
        contactForceComponent: int = 0,
        forcePotentialOperator: SymbolicConstant = SUM,
        forcePotentialExponent: float = 2,
        connectorPotentials: ConnectorPotentialArray = None,
        table: tuple = (),
        independentComponents: tuple = (),
    ):
        """This method creates a connector friction behavior option for a ConnectorSection object.
        Depending upon the arguments provided, the friction behavior can be Coulomb-like or
        hysteretic in nature.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                import connectorBehavior
                          connectorBehavior.ConnectorFriction
                          import odbConnectorBehavior
                          odbConnectorBehavior.ConnectorFriction

        Parameters
        ----------
        frictionModel
            A SymbolicConstant specifying the desired frictional response model. Possible values are
            PREDEFINED and USER_CUSTOMIZED. The default value is PREDEFINED.
        slipStyle
            A SymbolicConstant specifying the method of indicating the slip direction: either
            specified or computed based upon the force potential data. Possible values are SPECIFY
            and COMPUTE. The default value is SPECIFY.This argument is applicable only if
            **frictionModel** = USER_CUSTOMIZED.
        tangentDirection
            None or an Int specifying the direction for which the frictional behavior is specified.
            Possible values are 1 ≤≤ **tangentDirection** ≤≤ 6, indicating an available component of
            relative motion. This argument applies only if **frictionModel** = USER_CUSTOMIZED and if
            **slipStyle** = SPECIFY. The default value is None.
        stickStiffness
            None or a Float specifying the stick stiffness associated with the frictional behavior
            in the direction specified by **tangentDirection**. If this argument is omitted, Abaqus
            computes an appropriate number for the stick stiffness. The default value is None.
        componentType
            A SymbolicConstant specifying the type of the **independentComponents**. Possible values
            are POSITION, MOTION, and NO_INDEPENDENT_COMPONENTS. The default value is
            NO_INDEPENDENT_COMPONENTS.
        slipDependency
            A Boolean specifying whether the table data depend on accumulated slip. The default
            value is OFF.This argument applies only if **frictionModel** = USER_CUSTOMIZED.
        temperatureDependency
            A Boolean specifying whether the table data depend on temperature. The default value is
            OFF.This argument applies only if **frictionModel** = USER_CUSTOMIZED.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.This
            argument applies only if **frictionModel** = USER_CUSTOMIZED.
        useContactForceComponent
            A Boolean specifying whether the contact force component will be defined. The default
            value is OFF.This argument applies only if **frictionModel** = USER_CUSTOMIZED.
        contactForceStyle
            A SymbolicConstant specifying the method of indicating the contact force component
            direction: either specified or computed based on upon a DerivedComponent. Possible
            values are COMPONENT_NUMBER and DERIVED_COMPONENT. The default value is
            COMPONENT_NUMBER.This argument is applicable only if **frictionModel** = USER_CUSTOMIZED and
            if **useContactForceComponent** = ON.
        contactForceComponent
            An Int specifying the contact force component direction. This argument applies only if
            **frictionModel** = USER_CUSTOMIZED, if **useContactForceComponent** = ON, and if
            **contactForceStyle** = COMPONENT_NUMBER. The default value is 0.
        forcePotentialOperator
            A SymbolicConstant specifying the contribution operator for the force potential
            contributions. Possible values are SUM and MAXIMUM. The default value is SUM.This
            argument is applicable only if **frictionModel** = USER_CUSTOMIZED and if
            **slipStyle** = COMPUTE.
        forcePotentialExponent
            A Float specifying the number equal to the inverse of the overall exponent in the force
            potential definition. The default value is 2.0.This argument is applicable only if
            **frictionModel** = USER_CUSTOMIZED, if **slipStyle** = COMPUTE, and if
            **forcePotentialOperator** = SUM.
        connectorPotentials
            A :py:class:`~abaqus.Connector.ConnectorPotentialArray.ConnectorPotentialArray` object specifying one ConnectorPotential object for each force
            potential contribution. This member can be specified only if
            **frictionModel** = USER_CUSTOMIZED, and if **slipStyle** = COMPUTE.
        table
            A sequence of sequences of Floats specifying friction properties. The default value is
            an empty sequence.If **frictionModel** = PREDEFINED, each sequence of the table data
            specifies:If applicable, the first geometric scaling constant relevant to frictional
            interactions.Etc., up to as many geometric scaling constants as are associated with this
            connection type.Internal contact force/moment generating friction in the first
            predefined slip direction.If applicable, internal contact force/moment generating
            friction in the second predefined slip direction.Connector constitutive relative motion
            in the direction specified by **independentComponent**.Accumulated slip in the first
            predefined slip direction, if the data depend on accumulated slip.Temperature, if the
            data depend on temperature.Value of the first field variable, if the data depend on
            field variables.Value of the second field variable.Etc.If
            **frictionModel** = USER_CUSTOMIZED, each sequence of the table data specifies:Effective
            radius of the cylindrical or spherical surface over which frictional slip occurs in the
            connector associated with frictional effects in the direction specified by
            **tangentDirection**. This radius is relevant only if the connection type includes an
            available rotational component of relative motion and
            **tangentDirection** = SLIP_DIRECTION.Internal contact force/moment generating friction in
            the direction specified by **tangentDirection**.Connector constitutive relative motion in
            the direction specified by **independentComponent**.Accumulated slip in the direction
            specified by **tangentDirection**, if the data depend on accumulated slip.Temperature, if
            the data depend on temperature.Value of the first field variable, if the data depend on
            field variables.Value of the second field variable.Etc.
        independentComponents
            A sequence of Ints specifying the independent components. Possible values are 1 ≤≤
            **independentComponents** ≤≤ 6. In addition, each independent component value must be
            unique. The **independentComponents** argument applies only if
            **frictionModel** = USER_CUSTOMIZED. Only available components can be specified. The default
            value is an empty sequence.

        Returns
        -------
        ConnectorFriction
            A :py:class:`~abaqus.Connector.ConnectorFriction.ConnectorFriction` object.

        Raises
        ------
        ValueError and TextError
        """
        super().__init__()
        pass

    def setValues(self, *args, **kwargs):
        """This method modifies the ConnectorFriction object.

        Raises
        ------
        ValueError
        """
        pass



class SymbolicConstant:
    """The SymbolicConstant object represents a string in a way that can be stored in a replay
    file and used as an argument to Abaqus Scripting Interface methods and functions. By
    convention the string representation of the SymbolicConstant object is the same as its
    variable name. If you pass a SymbolicConstant object to the Python repr() function, the
    function returns the text without quotes. In effect, the text is the variable that, by
    convention, refers to the SymbolicConstant object.
    Two SymbolicConstant objects with the same text are the same Python object, although you
    can assign them to different variables. All of the SymbolicConstant objects that are
    required in Abaqus Scripting Interface methods are defined in the abaqusConstants
    module. Some SymbolicConstant objects and the SymbolicConstant constructor are defined
    in the abaqus module. The SymbolicConstant constructor is also defined in the
    symbolicConstants module.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            from symbolicConstants import *
            from abaqusConstants import *
    """

    def __init__(self, text: str):
        """The SymbolicConstant method creates a SymbolicConstant object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                SymbolicConstant

        Parameters
        ----------
        text
            A String specifying the text of the SymbolicConstant object. The String must contain
            only capital letters, digits, or underscores and must not start with a digit.

        Returns
        -------
        SymbolicConstant
            A :py:class:`~abaqus.UtilityAndView.SymbolicConstant.SymbolicConstant` object.
        """
        pass



class DrawingArea:
    """The DrawingArea object specifies the location and size of the drawing area used for
    placement of viewports.

    Notes
    -----
    This object can be accessed by:

    .. code-block::

        session.drawingArea
    """

    #: A Float specifying the width in millimeters.
    width: float = None

    #: A Float specifying the height in millimeters.
    height: float = None

    #: A pair of Floats specifying the coordinates of the bottom left hand corner in
    #: millimeters.
    origin: tuple[float, ...] = ()



from abaqusConstants import *


class LineStyle:
    """The LineStyle object is used to define the line style to be used for drawing XY-Plot
    objects.
    LineStyle objects can be created using the methods described below.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import visualization
            session.charts[name].area.border
            session.charts[name].axes1[i].axisData.curves[i].lineStyle
            session.charts[name].axes1[i].lineStyle
            session.charts[name].axes1[i].tickStyle
            session.charts[name].axes2[i].axisData.curves[i].lineStyle
            session.charts[name].axes2[i].lineStyle
            session.charts[name].axes2[i].tickStyle
            session.charts[name].curves[name].lineStyle
            session.charts[name].gridArea.border
            session.charts[name].legend.area.border
            session.charts[name].majorAxis1GridStyle
            session.charts[name].majorAxis2GridStyle
            session.charts[name].minorAxis1GridStyle
            session.charts[name].minorAxis2GridStyle
            session.charts[name].tagBorder
            session.curves[name].lineStyle
            session.defaultChartOptions.defaultAxis1Options.axisData.curves[i].lineStyle
            session.defaultChartOptions.defaultAxis1Options.lineStyle
            session.defaultChartOptions.defaultAxis1Options.tickStyle
            session.defaultChartOptions.defaultAxis2Options.axisData.curves[i].lineStyle
            session.defaultChartOptions.defaultAxis2Options.lineStyle
            session.defaultChartOptions.defaultAxis2Options.tickStyle
            session.defaultChartOptions.gridArea.border
            session.defaultChartOptions.legend.area.border
            session.defaultChartOptions.majorAxis1GridStyle
            session.defaultChartOptions.majorAxis2GridStyle
            session.defaultChartOptions.minorAxis1GridStyle
            session.defaultChartOptions.minorAxis2GridStyle
            session.defaultChartOptions.tagBorder
            session.defaultPlot.area.border
            session.defaultPlot.title.area.border
            session.xyPlots[name].area.border
            session.xyPlots[name].charts[name].area.border
            session.xyPlots[name].charts[name].axes1[i].axisData.curves[i].lineStyle
            session.xyPlots[name].charts[name].axes1[i].lineStyle
            session.xyPlots[name].charts[name].axes1[i].tickStyle
            session.xyPlots[name].charts[name].axes2[i].axisData.curves[i].lineStyle
            session.xyPlots[name].charts[name].axes2[i].lineStyle
            session.xyPlots[name].charts[name].axes2[i].tickStyle
            session.xyPlots[name].charts[name].curves[name].lineStyle
            session.xyPlots[name].charts[name].gridArea.border
            session.xyPlots[name].charts[name].legend.area.border
            session.xyPlots[name].charts[name].majorAxis1GridStyle
            session.xyPlots[name].charts[name].majorAxis2GridStyle
            session.xyPlots[name].charts[name].minorAxis1GridStyle
            session.xyPlots[name].charts[name].minorAxis2GridStyle
            session.xyPlots[name].charts[name].tagBorder
            session.xyPlots[name].curves[name].lineStyle
            session.xyPlots[name].title.area.border
    """

    #: A String specifying the color to be used when drawing a line with this LineStyle object.
    #: The default value is "White".
    color: str = ""

    #: A Boolean specifying whether to draw the line when using this LineStyle. The default
    #: value is ON.
    show: Boolean = ON

    #: A SymbolicConstant specifying the line style to be used when drawing lines using this
    #: LineStyle. Possible values are SOLID, DASHED, DOTTED, and DOT_DASH. The default value is
    #: SOLID.
    style: SymbolicConstant = SOLID

    #: A Float specifying the line thickness in mm to be used when drawing lines using this
    #: LineStyle. The default value is 0.2.
    thickness: float = 0

    def __init__(
        self,
        color: str = "",
        show: Boolean = ON,
        style: SymbolicConstant = SOLID,
        thickness: float = 0,
    ):
        """This method creates a LineStyle.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                session.LineStyle
                xyPlot.LineStyle

        Parameters
        ----------
        color
            A String specifying the color to be used when drawing a line with this LineStyle object.
            The default value is "White".
        show
            A Boolean specifying whether to draw the line when using this LineStyle. The default
            value is ON.
        style
            A SymbolicConstant specifying the line style to be used when drawing lines using this
            LineStyle. Possible values are SOLID, DASHED, DOTTED, and DOT_DASH. The default value is
            SOLID.
        thickness
            A Float specifying the line thickness in mm to be used when drawing lines using this
            LineStyle. The default value is 0.2.

        Returns
        -------
        LineStyle
            A :py:class:`~abaqus.XY.LineStyle.LineStyle` object.

        Raises
        ------
        ColorError
        """
        pass

    def setValues(
        self,
        color: str = "",
        show: Boolean = ON,
        style: SymbolicConstant = SOLID,
        thickness: float = 0,
    ):
        """This method modifies the LineStyle object.

        Parameters
        ----------
        color
            A String specifying the color to be used when drawing a line with this LineStyle object.
            The default value is "White".
        show
            A Boolean specifying whether to draw the line when using this LineStyle. The default
            value is ON.
        style
            A SymbolicConstant specifying the line style to be used when drawing lines using this
            LineStyle. Possible values are SOLID, DASHED, DOTTED, and DOT_DASH. The default value is
            SOLID.
        thickness
            A Float specifying the line thickness in mm to be used when drawing lines using this
            LineStyle. The default value is 0.2.
        """
        pass



from abaqusConstants import *


class AdaptiveMeshConstraintState:
    """The AdaptiveMeshConstraintState object is the abstract base type for other Arbitrary
    Lagrangian Eularian (ALE) style AdaptiveMeshConstraintState objects. The
    AdaptiveMeshConstraintState object has no explicit constructor or methods. The members
    of the AdaptiveMeshConstraintState object are common to all objects derived from the
    AdaptiveMeshConstraintState object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import step
            mdb.models[name].steps[name].adaptiveMeshConstraintStates[name]
    """

    #: A SymbolicConstant specifying the propagation state of the amplitude reference. Possible
    #: values are UNSET, SET, UNCHANGED, FREED, and MODIFIED.
    amplitudeState: SymbolicConstant = None

    #: A SymbolicConstant specifying the propagation state of the AdaptiveMeshConstraintState
    #: object. Possible values are:
    #: 
    #: - NOT_YET_ACTIVE
    #: - CREATED
    #: - PROPAGATED
    #: - MODIFIED
    #: - DEACTIVATED
    #: - NO_LONGER_ACTIVE
    #: - TYPE_NOT_APPLICABLE
    #: - INSTANCE_NOT_APPLICABLE
    #: - PROPAGATED_FROM_BASE_STATE
    #: - MODIFIED_FROM_BASE_STATE
    #: - DEACTIVATED_FROM_BASE_STATE
    #: - BUILT_INTO_MODES
    status: SymbolicConstant = None

    #: A String specifying the name of the amplitude reference. The String is empty if the
    #: adaptive mesh constraint has no amplitude reference.
    amplitude: str = ""

    def __init__(
        self,
        amplitudeState: SymbolicConstant = None,
        status: SymbolicConstant = None,
        amplitude: str = "",
    ):
        """The AdaptiveMeshConstraintState object is the abstract base type for other Arbitrary
        Lagrangian Eularian (ALE) style AdaptiveMeshConstraintState objects. The
        AdaptiveMeshConstraintState object has no explicit constructor or methods. The members
        of the AdaptiveMeshConstraintState object are common to all objects derived from the
        AdaptiveMeshConstraintState object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].steps[name].AdaptiveMeshConstraintState

        Parameters
        ----------
        amplitudeState
            A SymbolicConstant specifying the propagation state of the amplitude reference. Possible  values are
            UNSET, SET, UNCHANGED, FREED, and MODIFIED.
        status
            A SymbolicConstant specifying the propagation state of the AdaptiveMeshConstraintState  object. Possible
            values are:
             
            - NOT_YET_ACTIVE
            - CREATED
            - PROPAGATED
            - MODIFIED
            - DEACTIVATED
            - NO_LONGER_ACTIVE
            - TYPE_NOT_APPLICABLE
            - INSTANCE_NOT_APPLICABLE
            - PROPAGATED_FROM_BASE_STATE
            - MODIFIED_FROM_BASE_STATE
            - DEACTIVATED_FROM_BASE_STATE
            - BUILT_INTO_MODES
            
        amplitude
            A String specifying the name of the amplitude reference. The String is empty if the  adaptive mesh
            constraint has no amplitude reference.
        """
        pass



from abaqusConstants import *


class StreamOptions:
    """The StreamOptions object stores values and attributes associated with a stream plot. The
    StreamOptions object has no constructor command. Abaqus creates a
    *defaultOdbDisplay.streamOptions* member when you import the Visualization module.
    Abaqus creates a **StreamOptions** member when it creates the OdbDisplay object, using the
    values from *defaultOdbDisplay.streamOptions*. Abaqus creates the **odbDisplay** member
    when a viewport is created, using the values from **defaultOdbDisplay**.
    StreamOptions objects are accessed in one of two ways:
    - The default stream options. These settings are used as defaults when other
    **streamOptions** members are created. These settings can be set to customize user
    preferences.
    - The stream options associated with a particular viewport.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import visualization
            session.defaultOdbDisplay.streamOptions
            session.viewports[name].layers[name].odbDisplay.streamOptions
            session.viewports[name].odbDisplay.streamOptions
    """

    def setValues(
        self,
        colorMethod: SymbolicConstant = UNIFORM,
        uniformColor: str = "",
        lineThickness: float = 6,
        showArrow: Boolean = OFF,
        numArrows: int = 10,
    ):
        """This method modifies the StreamOptions object.

        Parameters
        ----------
        colorMethod
            A SymbolicConstant specifying the method for coloring stream lines. Possible values are
            UNIFORM, SPECTRUM, and CONTINUOUS. The default value is UNIFORM.
        uniformColor
            A String specifying uniform color of the stream lines. The default value is "#FFFF00".
        lineThickness
            A Float specifying the stream line thickness. The default value is 6.0.
        showArrow
            A Boolean specifying whether to show arrows. The default value is OFF.
        numArrows
            An Int specifying the number of arrows on each stream line. The default value is 10.
        """
        pass



from abaqusConstants import *
from ..Region.Region import Region


class CompositePly:
    """The CompositePly object defines the material layers in a composite layup.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import section
            mdb.models[name].parts[name].compositeLayups[i].plies[i]
    """

    #: A Float specifying the thickness of the section layer.
    thickness: float

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the composite ply applies.
    region: Region

    #: A String specifying the name of the material for the ply.
    material: str

    #: A String specifying the ply identifier for this section layer. The default value is an
    #: empty string.
    plyName: str

    #: A SymbolicConstant specifying the method used to define the relative orientation. If
    #: **orientationType** = SPECIFY_ORIENT the **orientationValue** argument is required. If
    #: **orientationType** = CSYS the **orientation** argument is required. Possible values are CSYS,
    #: SPECIFY_ORIENT, ANGLE_0, ANGLE_45, ANGLE_90, and ANGLE_NEG45. The default value is
    #: ANGLE_0.
    orientationType: SymbolicConstant

    #: A SymbolicConstant specifying the method used to define the thickness. If
    #: thicknessType=SPECIFY_THICKNESS, the thickness argument is required.
    #: Possible values are SPECIFY_THICKNESS and FIELD_THICKNESS. The default
    #: value is SPECIFY_THICKNESS.
    thicknessType: SymbolicConstant

    #: A Float specifying the relative orientation of the section layer. The default value is
    #: 0.0.
    orientationValue: float = 0

    #: A String specifying the name of the AnalyticalField or DiscreteField object used to
    #: define the thickness of the shell elements. The thicknessField argument applies only
    #: when thicknessType=ANALYTICAL_FIELD or thicknessType=DISCRETE_FIELD. The default
    #: value is an empty string.
    thicknessField: str = ""

    #: An Int specifying the number of integration points to be used through the section layer.
    #: This argument is valid only if **preIntegrate** = OFF. The default value is 3.
    numIntPts: int = 3

    #: A SymbolicConstant specifying the axis of a cylindrical or spherical datum coordinate
    #: system about which an additional rotation is applied. For shells this axis is also the
    #: shell normal. The **axis** argument applies only if a valid reference is provided for the
    #: **orientation**. Possible values are AXIS_1, AXIS_2, and AXIS_3. The default value is
    #: AXIS_1.
    axis: SymbolicConstant = AXIS_1

    #: A Float specifying the angle of the additional rotation. The **angle** argument applies
    #: only if a valid reference is provided for the **orientation**. The default value is 0.0.
    angle: float = 0

    #: A SymbolicConstant specifying the method used to describe the additional rotation when a
    #: valid orientation is specified. Use **orientationType** = ANGLE_0 and
    #: **additionalRotationType** = ROTATION_FIELD to specify a discrete field of rotations for
    #: this CompositePly. Possible values are ROTATION_NONE, ROTATION_ANGLE, and
    #: ROTATION_FIELD. The default value is ROTATION_NONE.
    additionalRotationType: SymbolicConstant = ROTATION_NONE

    #: The SymbolicConstant None or a DatumCsys object specifying a coordinate system reference
    #: for the relative orientation of this layer. The default value is None.
    orientation: SymbolicConstant = None

    #: A String specifying the name of the field specifying the additional rotation. The
    #: default value is an empty string.
    additionalRotationField: str = ""

    def __init__(
        self,
        thickness: float,
        region: Region,
        material: str,
        plyName: str,
        orientationType: SymbolicConstant,
        thicknessType: SymbolicConstant,
        orientationValue: float = 0,
        thicknessField: str = "",
        numIntPts: int = 3,
        axis: SymbolicConstant = AXIS_1,
        angle: float = 0,
        additionalRotationType: SymbolicConstant = ROTATION_NONE,
        orientation: SymbolicConstant = None,
        additionalRotationField: str = "",
    ):
        """This method creates a CompositePly object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].parts[name].compositeLayups[name].CompositePly

        Parameters
        ----------
        thickness
            A Float specifying the thickness of the section layer.
        region
            A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the composite ply applies.
        material
            A String specifying the name of the material for the ply.
        plyName
            A String specifying the ply identifier for this section layer. The default value is an
            empty string.
        orientationType
            A SymbolicConstant specifying the method used to define the relative orientation. If
            **orientationType** = SPECIFY_ORIENT the **orientationValue** argument is required. If
            **orientationType** = CSYS the **orientation** argument is required. Possible values are CSYS,
            SPECIFY_ORIENT, ANGLE_0, ANGLE_45, ANGLE_90, and ANGLE_NEG45. The default value is
            ANGLE_0.
        thicknessType
            A SymbolicConstant specifying the method used to define the thickness. If
            **thicknessType** = SPECIFY_THICKNESS, the **thickness** argument is required. Possible values
            are SPECIFY_THICKNESS, FIELD_THICKNESS, and ANALYTICAL_FIELD_THICKNESS. The default
            value is SPECIFY_THICKNESS.
        orientationValue
            A Float specifying the relative orientation of the section layer. The default value is
            0.0.
        thicknessField
            A String specifying the name of the AnalyticalField or DiscreteField object used to
            define the thickness of the shell elements. The thicknessField argument applies only
            when thicknessType=ANALYTICAL_FIELD or thicknessType=DISCRETE_FIELD. The default
            value is an empty string.

            A String specifying the name of the AnalyticalField or DiscreteField object used to
            define the thickness of the shell elements and composite ply. The **thicknessField**
            argument applies when **thicknessType** = ANALYTICAL_FIELD or **thicknessType** = DISCRETE_FIELD
            for shell elements and **thicknessType** = FIELD_THICKNESS or
            **thicknessType** = ANALYTICAL_FIELD_THICKNESS for composite ply. The default value is an
            empty string.
        numIntPts
            An Int specifying the number of integration points to be used through the section layer.
            This argument is valid only if **preIntegrate** = OFF. The default value is 3.
        axis
            A SymbolicConstant specifying the axis of a cylindrical or spherical datum coordinate
            system about which an additional rotation is applied. For shells this axis is also the
            shell normal. The **axis** argument applies only if a valid reference is provided for the
            **orientation**. Possible values are AXIS_1, AXIS_2, and AXIS_3. The default value is
            AXIS_1.
        angle
            A Float specifying the angle of the additional rotation. The **angle** argument applies
            only if a valid reference is provided for the **orientation**. The default value is 0.0.
        additionalRotationType
            A SymbolicConstant specifying the method used to describe the additional rotation when a
            valid orientation is specified. Use **orientationType** = ANGLE_0 and
            **additionalRotationType** = ROTATION_FIELD to specify a discrete field of rotations for
            this CompositePly. Possible values are ROTATION_NONE, ROTATION_ANGLE, and
            ROTATION_FIELD. The default value is ROTATION_NONE.
        orientation
            The SymbolicConstant None or a DatumCsys object specifying a coordinate system reference
            for the relative orientation of this layer. The default value is None.
        additionalRotationField
            A String specifying the name of the field specifying the additional rotation. The
            default value is an empty string.

        Returns
        -------
        CompositePly
            A :py:class:`~abaqus.Property.CompositePly.CompositePly` object.

        Raises
        ------
        AbaqusException
        """
        pass



import typing

from abaqusConstants import *


class SurfaceFrictionAssignment:
    """The SurfaceFrictionAssignment object stores the surface friction assignment definition
    for surfaces in ContactExp objects. The SurfaceFrictionAssignment object has no
    constructor or members.

    .. note::
        This object can be accessed by:

        .. code-block:: python

            import interaction
            mdb.models[name].interactions[name].surfaceFrictionAssignments

    The corresponding analysis keywords are:

    - SURFACE PROPERTY ASSIGNMENT

    """

    def changeValuesInStep(self, stepName: str, index: int, value: float):
        """This method allows modification of surface friction assignments already defined on
        surfaces in a given step.

        Parameters
        ----------
        stepName
            A String specifying the name of the step in which the surface friction assignments are
            to be modified.
        index
            An Int specifying the position of the surface friction assignment whose value is to be
            modified.
        value
            A tuple specifying the value of the surface friction assignments for the surface whose
            index is referenced. Each tuple contains:
            - A Float specifying the overriding friction coefficient value to be used in the contact
            definition.
        """
        pass

    def appendInStep(
        self, stepName: str, assignments: typing.Union[SymbolicConstant, float]
    ):
        """This method allows addition of surface friction assignments to new surfaces in a given
        step.

        Parameters
        ----------
        stepName
            A String specifying the name of the step in which new surface friction assignments are
            to be defined.
        assignments
            A sequence of tuples specifying the surface friction assignments. Each tuple contains
            two entries:
            - A region or a material object or the SymbolicConstant GLOBAL specifying the surface to
            which the friction coefficient is assigned.
            - A Float specifying the overriding friction coefficient to be used in the contact
            definition.
        """
        pass

    def delete(self, indices: tuple):
        """The delete method allows you to delete existing surface friction assignments.

        Parameters
        ----------
        indices
            A sequence of Ints specifying the index of each surface friction assignment to delete.
        """
        pass



from abaqusConstants import *
from .InteractionState import InteractionState


class FluidCavityState(InteractionState):
    """The FluidCavityState object stores the propagating data for an FluidCavity object. One
    instance of this object is created internally by the FluidCavity object for each step.
    The instance is also deleted internally by the FluidCavity object.
    The FluidCavityState object has no constructor or methods.
    The FluidCavityState object is derived from the InteractionState object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import interaction
            mdb.models[name].steps[name].interactionStates[name]
    """

    #: A SymbolicConstant specifying the propagation state of the InteractionState object.
    #: Possible values are:
    #: 
    #: - NOT_YET_ACTIVE
    #: - CREATED
    #: - PROPAGATED
    #: - MODIFIED
    #: - DEACTIVATED
    #: - NO_LONGER_ACTIVE
    #: - TYPE_NOT_APPLICABLE
    #: - INSTANCE_NOT_APPLICABLE
    #: - BUILT_INTO_BASE_STATE
    status: SymbolicConstant = None



from .CommandRegister import CommandRegister


class RegisteredList(CommandRegister):
    """This class allows you to create a list that can be queried from the GUI and is capable
    of notifying the GUI when the contents of the list change.
    The RegisteredList object is derived from the CommandRegister object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import customKernel
    """

    def __init__(self):
        """This method creates a RegisteredList object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                customKernel.RegisteredList

        Returns
        -------
        RegisteredList
            A :py:class:`~abaqus.CustomKernel.RegisteredList.RegisteredList` object.
        """
        super().__init__()
        pass

    def Methods(self):
        """The RegisteredList object supports the same methods as a standard Python list object."""
        pass



from abaqusConstants import *
from .LoadState import LoadState


class ConcentratedHeatFluxState(LoadState):
    """The ConcentratedHeatFluxState object stores the propagating data of a concentrated heat
        flux load in a step. One instance of this object is created internally by the
        ConcentratedHeatFlux object for each step. The instance is also deleted internally by
        the ConcentratedHeatFlux object.
        The ConcentratedHeatFluxState object has no constructor or methods.
        The ConcentratedHeatFluxState object is derived from the LoadState object.

        Attributes
        ----------
        magnitude: float
            A Float specifying the load magnitude.
        magnitudeState: SymbolicConstant
            A SymbolicConstant specifying the propagation state of the load magnitude. Possible
            values are UNSET, SET, UNCHANGED, and FREED.
        amplitudeState: SymbolicConstant
            A SymbolicConstant specifying the propagation state of the **amplitude** member. Possible
            values are UNSET, SET, UNCHANGED, and FREED.
        status: SymbolicConstant
            A SymbolicConstant specifying the propagation state of the :py:class:`~abaqus.Load.LoadState.LoadState` object. Possible
            values are:
            
            - NOT_YET_ACTIVE
            - CREATED
            - PROPAGATED
            - MODIFIED
            - DEACTIVATED
            - NO_LONGER_ACTIVE
            - TYPE_NOT_APPLICABLE
            - INSTANCE_NOT_APPLICABLE
            - BUILT_INTO_BASE_STATE
        amplitude: str
            A String specifying the name of the amplitude reference. The String is empty if the load
            has no amplitude reference.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import load
                mdb.models[name].steps[name].loadStates[name]

            The corresponding analysis keywords are:

            - CFLUX
    """

    #: A Float specifying the load magnitude.
    magnitude: float = None

    #: A SymbolicConstant specifying the propagation state of the load magnitude. Possible
    #: values are UNSET, SET, UNCHANGED, and FREED.
    magnitudeState: SymbolicConstant = None

    #: A SymbolicConstant specifying the propagation state of the **amplitude** member. Possible
    #: values are UNSET, SET, UNCHANGED, and FREED.
    amplitudeState: SymbolicConstant = None

    #: A SymbolicConstant specifying the propagation state of the LoadState object. Possible
    #: values are:
    #: 
    #: - NOT_YET_ACTIVE
    #: - CREATED
    #: - PROPAGATED
    #: - MODIFIED
    #: - DEACTIVATED
    #: - NO_LONGER_ACTIVE
    #: - TYPE_NOT_APPLICABLE
    #: - INSTANCE_NOT_APPLICABLE
    #: - BUILT_INTO_BASE_STATE
    status: SymbolicConstant = None

    #: A String specifying the name of the amplitude reference. The String is empty if the load
    #: has no amplitude reference.
    amplitude: str = ""



class GraphicsInfo:
    """The GraphicsInfo object stores information about the graphics adapter installed in your
    system. The GraphicsInfo object has no constructor or methods; Abaqus creates the
    **GraphicsInfo** member when a session is started.
    If you execute Abaqus/CAE on a remote system and display the main window locally, the
    *glx server* is your local machine and the *glx client* is the remote machine. This
    definition of client and server follows the X11 naming convention. If you execute and
    display Abaqus/CAE on the same machine, you will typically see identical values for both
    the name of the server and the name of the client.
    The members are all read-only.

    Notes
    -----
    This object can be accessed by:

    .. code-block::

        session.graphicsInfo
    """

    #: A sequence of the type (Int, Int, String) specifying the three components of the OpenGL
    #: version. The sequence consists of an Int with the OpenGL major version number, an Int
    #: with the OpenGL minor version number, and a String with any additional information.
    glVersion: tuple = ()

    #: A sequence of the type (Int, Int, String) specifying the three components of the glx
    #: version of the server. The sequence consists of an Int with the glx major version
    #: number, an Int with the glx minor version number, and a String with any additional
    #: information.
    glxServerVersion: tuple = ()

    #: A sequence of the type (Int, Int, String) specifying the three components of the of glx
    #: version of the client. The sequence consists of an Int with the glx major version
    #: number, an Int with the glx minor version number, and String with any additional
    #: information.
    glxClientVersion: tuple = ()

    #: A String specifying the graphics adapter vendor. On hardware accelerated systems
    #: **glVendor** specifies the vendor that manufactured the adapter. On systems without
    #: hardware acceleration **glVendor** specifies the developer of the software graphics
    #: library.
    glVendor: str = ""

    #: A String specifying the name of the rendering device or the name of the software
    #: graphics library.
    glRenderer: str = ""

    #: A String specifying the glx developer on the server side.
    glxServerVendor: str = ""

    #: A String specifying the glx developer on the client side.
    glxClientVendor: str = ""



from .ConstrainedSketchConstraint import ConstrainedSketchConstraint
from ..ConstrainedSketchGeometry.ConstrainedSketchGeometry import (
    ConstrainedSketchGeometry,
)


class ParallelConstraint(ConstrainedSketchConstraint):
    def __init__(
        self, entity1: ConstrainedSketchGeometry, entity2: ConstrainedSketchGeometry
    ):
        """This method creates a parallel constraint. This constraint applies to lines and
        constrains them to be parallel.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].sketches[name].ParallelConstraint

        Parameters
        ----------
        entity1
            A :py:class:`~abaqus.Sketcher.ConstrainedSketchGeometry.ConstrainedSketchGeometry.ConstrainedSketchGeometry` object specifying the first line.
        entity2
            A :py:class:`~abaqus.Sketcher.ConstrainedSketchGeometry.ConstrainedSketchGeometry.ConstrainedSketchGeometry` object specifying the second line.

        Returns
        -------
        ConstrainedSketchConstraint
            A :py:class:`~abaqus.Sketcher.ConstrainedSketchConstraint.ConstrainedSketchConstraint.ConstrainedSketchConstraint` object.

        """
        pass



from .StructuralDampingByFrequencyComponent import StructuralDampingByFrequencyComponent


class StructuralDampingByFrequencyComponentArray(
    list[StructuralDampingByFrequencyComponent]
):
    def findAt(self):
        pass



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="abqpy",
    version="2022a10",
    author="WANG Hailin",
    author_email="hailin.wang@connect.polyu.hk",
    description="Type hints for Abaqus/Python scripting",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/haiiliin/abqpy",
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    project_urls={
        'GitHub': 'https://github.com/haiiliin/abqpy',
        'Bug Tracker': 'https://github.com/haiiliin/abqpy/issues',
        'Pull Requests': 'https://github.com/haiiliin/abqpy/pulls',
        'Discussions': 'https://github.com/haiiliin/abqpy/discussions',
        'Documentation': 'https://abqpy.haiiliin.com',
        'Anaconda': 'https://anaconda.org/haiiliin/abqpy',
        'Read the Docs': 'https://readthedocs.org/projects/abqpy',
    },
    python_requires='>=3.9',
    package_dir={'': 'src'},
    install_requires=['ipyparams', 'typing-extensions'],
    packages=setuptools.find_packages('src'),
    py_modules=['abaqusConstants', 'animation', 'annotationToolset', 'assembly', 'caeModules', 'caePrefsAccess',
                'calibration', 'connectorBehavior', 'customKernel', 'deleteObjectCallback', 'displayGroupMdbToolset',
                'displayGroupOdbToolset', 'driverUtils', 'field', 'fields', 'inpParser', 'interaction', 'material',
                'mesh', 'meshEdit', 'methodCallback', 'monitorManager', 'odbAccess', 'odbConnectorBehavior',
                'odbMaterial', 'odbSection', 'part', 'redentABQ', 'section', 'symbolicConstants', 'textRepr',
                'upgradeScript', 'visualization'],
)



from .Section import Section
from .TransverseShearShell import TransverseShearShell


class ShellSection(Section):
    """The ShellSection object defines the properties of a shell section. The ShellSection
    object is derived from the Section object. The ShellSection object has no explicit
    constructor and no methods or members.
    The ShellSection object is derived from the Section object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import section
            mdb.models[name].sections[name]
            import odbSection
            session.odbs[name].sections[name]
    """

    #: A String specifying the repository key.
    name: str = ""

    #: A :py:class:`~abaqus.Section.TransverseShearShell.TransverseShearShell` object specifying the transverse shear stiffness properties.
    transverseShear: TransverseShearShell = None



from abaqusConstants import *
from .DisplayGroupArray import DisplayGroupArray
from .Leaf import Leaf


class LeafFromDisplayGroup(Leaf):
    """The LeafFromDisplayGroup object can be used whenever a Leaf object is expected as an
    argument. Leaf objects are used to specify the items in a display group. Leaf objects
    are constructed as temporary objects, which are then used as arguments to DisplayGroup
    commands.The LeafFromDisplayGroup object is derived from the Leaf object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import displayGroupMdbToolset
            import displayGroupOdbToolset
    """

    #: A SymbolicConstant specifying the leaf type. Possible values are EMPTY_LEAF,
    #: DEFAULT_MODEL, ALL_ELEMENTS, ALL_NODES, and ALL_SURFACES.
    leafType: SymbolicConstant = None

    #: A :py:class:`~abaqus.DisplayGroup.DisplayGroupArray.DisplayGroupArray` object.
    displayGroup: DisplayGroupArray

    def __init__(self, displayGroup: DisplayGroupArray):
        """This method creates a Leaf object from a sequence of Display Group objects.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                LeafFromDisplayGroup

        Parameters
        ----------
        displayGroup
            A :py:class:`~abaqus.DisplayGroup.DisplayGroupArray.DisplayGroupArray` object.

        Returns
        -------
        LeafFromDisplayGroup
            A :py:class:`~abaqus.DisplayGroup.LeafFromDisplayGroup.LeafFromDisplayGroup` object.
        """
        super().__init__(DEFAULT_MODEL)
        pass



from .Behavior import Behavior
from .DataSet import DataSet


class Calibration:
    """A :py:class:`~abaqus.BoundaryCondition.Calibration.Calibration` object is the object used to specify a material calibration. The
    Calibration object stores the data that is used for specifying materials from test data.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import calibration
            mdb.models[name].calibrations[name]
    """

    #: A :py:class:`~abaqus.Calibration.DataSet.DataSet` object.
    dataSets: DataSet = None

    #: A :py:class:`~abaqus.Calibration.Behavior.Behavior` object.
    behaviors: Behavior = None

    #: A String specifying the name of the new calibration.
    name: str

    def __init__(self, name: str):
        """This method creates a Calibration object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].Calibration

        Parameters
        ----------
        name
            A String specifying the name of the new calibration.

        Returns
        -------
        Calibration
            A :py:class:`~abaqus.BoundaryCondition.Calibration.Calibration` object.
        """
        pass

    def Behavior(self, name: str, typeName: str) -> Behavior:
        """This method creates a Behavior object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].Calibration

        Parameters
        ----------
        name
            A String specifying the name of the new behavior.
        typeName
            A String specifying the type of the new Behavior. Values can be "ElasIsoBehavior",
            "ElasPlasIsoBehavior", "FeFpBehavior", or a user plug-in behavior type.

        Returns
        -------
        Behavior
            A :py:class:`~abaqus.Calibration.Behavior.Behavior` object.
        """
        self.behaviors = behavior = Behavior(name, typeName)
        return behavior

    def DataSet(
        self, name: str, data: tuple = (), type: str = "", form: str = ""
    ) -> DataSet:
        """This method creates a DataSet object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].Calibration

        Parameters
        ----------
        name
            A String specifying the name of the new dataset.
        data
            A sequence of pairs of Floats specifying data set type pairs. Possible values are for
            stress/strain, force/displacement, or transverse strain/axial strain pairs.
        type
            A String specifying the type of the new dataset. Values can be "STRESS/STRAIN",
            "FORCE/DISPLACEMENT", or "AXIALSTRAIN/TRANSVERSESTRAIN". The default value is
            "STRESS/STRAIN".
        form
            A String specifying the form of the new dataset. Values can be "NOMINAL" or "TRUE". The
            default value is "NOMINAl".

        Returns
        -------
        DataSet
            A :py:class:`~abaqus.Calibration.DataSet.DataSet` object.
        """
        self.dataSets = dataSet = DataSet(name, data, type, form)
        return dataSet



from abaqusConstants import *
from .AnalysisStep import AnalysisStep
from ..Adaptivity.AdaptiveMeshConstraintState import AdaptiveMeshConstraintState
from ..Adaptivity.AdaptiveMeshDomain import AdaptiveMeshDomain
from ..BoundaryCondition.BoundaryConditionState import BoundaryConditionState
from ..Load.LoadCase import LoadCase
from ..Load.LoadState import LoadState
from ..PredefinedField.PredefinedFieldState import PredefinedFieldState
from ..StepMiscellaneous.Control import Control
from ..StepMiscellaneous.SolverControl import SolverControl
from ..StepOutput.DiagnosticPrint import DiagnosticPrint
from ..StepOutput.FieldOutputRequestState import FieldOutputRequestState
from ..StepOutput.HistoryOutputRequestState import HistoryOutputRequestState
from ..StepOutput.Monitor import Monitor
from ..StepOutput.Restart import Restart


class DirectCyclicStep(AnalysisStep):
    """The DirectCyclicStep object is used to provide a direct cyclic procedure for nonlinear,
    non-isothermal quasi-static analysis. It can also be used to predict progressive damage
    and failure for ductile bulk materials and/or to predict delamination/debonding growth
    at the interfaces in laminated composites in a low-cycle fatigue analysis.
    The DirectCyclicStep object is derived from the AnalysisStep object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import step
            mdb.models[name].steps[name]

        The corresponding analysis keywords are:

        - DIRECT CYCLIC
                - STEP
    """

    #: A String specifying the repository key.
    name: str = ""

    #: A Float specifying the time of single loading cycle. The default value is 1.0.
    timePeriod: float = 1

    #: A SymbolicConstant specifying the time incrementation method to be used. Possible values
    #: are FIXED and AUTOMATIC. The default value is AUTOMATIC.
    timeIncrementationMethod: SymbolicConstant = AUTOMATIC

    #: An Int specifying the maximum number of increments in a step. The default value is 100.
    maxNumInc: int = 100

    #: A Float specifying the initial time increment. The default value is the total time
    #: period for the step.
    initialInc: float = None

    #: A Float specifying the minimum time increment allowed. The default value is the smaller
    #: of the suggested initial time increment or 10−5 times the total time period.
    minInc: float = None

    #: A Float specifying the maximum time increment allowed. The default value is the total
    #: time period for the step.
    maxInc: float = None

    #: An Int specifying the maximum number of iterations in a step. The default value is 200.
    maxNumIterations: int = 200

    #: An Int specifying the initial number of terms in the Fourier series. The default value
    #: is 11.
    initialTerms: int = 11

    #: An Int specifying the maximum number of terms in the Fourier series. The default value
    #: is 25.
    maxTerms: int = 25

    #: An Int specifying the increment in number of terms in the Fourier series. The default
    #: value is 5.
    termsIncrement: int = 5

    #: A Float specifying the maximum temperature change to be allowed in an increment. The
    #: default value is 0.0.
    deltmx: float = 0

    #: A Float specifying the maximum difference in the creep strain increment calculated from
    #: the creep strain rates at the beginning and end of the increment. The default value is
    #: 0.0.
    cetol: float = 0

    #: A Boolean specifying whether to include low-cycle fatigue analysis. The default value is
    #: OFF.
    fatigue: Boolean = OFF

    #: A Boolean specifying whether the displacement solution in the Fourier series obtained in
    #: the previous direct cyclic step is used as the starting values for the current step. The
    #: default value is OFF.
    continueAnalysis: Boolean = OFF

    #: An Int specifying the minimum number of cycles over which the damage is extrapolated
    #: forward. The default value is 100.
    minCycleInc: int = 100

    #: An Int specifying the maximum number of cycles over which the damage is extrapolated
    #: forward. The default value is 1000.
    maxCycleInc: int = 1000

    #: The SymbolicConstant DEFAULT or an Int specifying the maximum number of cycles allowed
    #: in a step or DEFAULT. A value of 1 plus half of the maximum number of cycles will be
    #: used if DEFAULT is specified. The default value is DEFAULT.
    maxNumCycles: SymbolicConstant = DEFAULT

    #: A Float specifying the maximum extrapolated damage increment. The default value is 1.0.
    damageExtrapolationTolerance: float = 1

    #: A SymbolicConstant specifying the type of matrix storage. Possible values are SYMMETRIC,
    #: UNSYMMETRIC, and SOLVER_DEFAULT. The default value is SOLVER_DEFAULT.
    matrixStorage: SymbolicConstant = SOLVER_DEFAULT

    #: A SymbolicConstant specifying the type of extrapolation to use in determining the
    #: incremental solution for a nonlinear analysis. Possible values are NONE, LINEAR, and
    #: PARABOLIC. The default value is LINEAR.
    extrapolation: SymbolicConstant = LINEAR

    #: A SymbolicConstant specifying whether to force a new iteration if severe discontinuities
    #: occur during an iteration. Possible values are PROPAGATED, CONVERT_SDI_OFF, and
    #: CONVERT_SDI_ON. The default value is PROPAGATED.
    convertSDI: SymbolicConstant = PROPAGATED

    #: A String specifying the name of the previous step. The new step appears after this step
    #: in the list of analysis steps.
    previous: str = ""

    #: A String specifying a description of the new step. The default value is an empty string.
    description: str = ""

    #: None or a String specifying a String specifying the name of a time point object used to
    #: determine at which times the response of the structure will be evaluated. The default
    #: value is NONE.
    timePoints: str = NONE

    #: A SymbolicConstant specifying whether the step has an explicit procedure type
    #: (*procedureType*=ANNEAL, DYNAMIC_EXPLICIT, or DYNAMIC_TEMP_DISPLACEMENT).
    explicit: SymbolicConstant = None

    #: A Boolean specifying whether the step has a perturbation procedure type.
    perturbation: Boolean = OFF

    #: A Boolean specifying whether the step has a mechanical procedure type.
    nonmechanical: Boolean = OFF

    #: A SymbolicConstant specifying the Abaqus procedure. Possible values are:
    #: 
    #: - ANNEAL
    #: - BUCKLE
    #: - COMPLEX_FREQUENCY
    #: - COUPLED_TEMP_DISPLACEMENT
    #: - COUPLED_THERMAL_ELECTRIC
    #: - DIRECT_CYCLIC
    #: - DYNAMIC_IMPLICIT
    #: - DYNAMIC_EXPLICIT
    #: - DYNAMIC_SUBSPACE
    #: - DYNAMIC_TEMP_DISPLACEMENT
    #: - COUPLED_THERMAL_ELECTRICAL_STRUCTURAL
    #: - FREQUENCY
    #: - GEOSTATIC
    #: - HEAT_TRANSFER
    #: - MASS_DIFFUSION
    #: - MODAL_DYNAMICS
    #: - RANDOM_RESPONSE
    #: - RESPONSE_SPECTRUM
    #: - SOILS
    #: - STATIC_GENERAL
    #: - STATIC_LINEAR_PERTURBATION
    #: - STATIC_RIKS
    #: - STEADY_STATE_DIRECT
    #: - STEADY_STATE_MODAL
    #: - STEADY_STATE_SUBSPACE
    #: - VISCO
    procedureType: SymbolicConstant = None

    #: A Boolean specifying whether the step is suppressed or not. The default value is OFF.
    suppressed: Boolean = OFF

    #: A repository of FieldOutputRequestState objects.
    fieldOutputRequestState: dict[str, FieldOutputRequestState] = dict[
        str, FieldOutputRequestState
    ]()

    #: A repository of HistoryOutputRequestState objects.
    historyOutputRequestState: dict[str, HistoryOutputRequestState] = dict[
        str, HistoryOutputRequestState
    ]()

    #: A :py:class:`~abaqus.StepOutput.DiagnosticPrint.DiagnosticPrint` object.
    diagnosticPrint: DiagnosticPrint = DiagnosticPrint()

    #: A :py:class:`~abaqus.StepOutput.Monitor.Monitor` object.
    monitor: Monitor = None

    #: A :py:class:`~abaqus.StepOutput.Restart.Restart` object.
    restart: Restart = Restart()

    #: A repository of AdaptiveMeshConstraintState objects.
    adaptiveMeshConstraintStates: dict[str, AdaptiveMeshConstraintState] = dict[
        str, AdaptiveMeshConstraintState
    ]()

    #: A repository of AdaptiveMeshDomain objects.
    adaptiveMeshDomains: dict[str, AdaptiveMeshDomain] = dict[str, AdaptiveMeshDomain]()

    #: A :py:class:`~abaqus.StepMiscellaneous.Control.Control` object.
    control: Control = Control()

    #: A :py:class:`~abaqus.StepMiscellaneous.SolverControl.SolverControl` object.
    solverControl: SolverControl = SolverControl()

    #: A repository of BoundaryConditionState objects.
    boundaryConditionStates: dict[str, BoundaryConditionState] = dict[
        str, BoundaryConditionState
    ]()

    #: A repository of InteractionState objects.
    interactionStates: int = None

    #: A repository of LoadState objects.
    loadStates: dict[str, LoadState] = dict[str, LoadState]()

    #: A repository of LoadCase objects.
    loadCases: dict[str, LoadCase] = dict[str, LoadCase]()

    #: A repository of PredefinedFieldState objects.
    predefinedFieldStates: dict[str, PredefinedFieldState] = dict[
        str, PredefinedFieldState
    ]()

    def __init__(
        self,
        name: str,
        previous: str,
        description: str = "",
        timePeriod: float = 1,
        timeIncrementationMethod: SymbolicConstant = AUTOMATIC,
        maxNumInc: int = 100,
        initialInc: float = None,
        minInc: float = None,
        maxInc: float = None,
        maxNumIterations: int = 200,
        initialTerms: int = 11,
        maxTerms: int = 25,
        termsIncrement: int = 5,
        deltmx: float = 0,
        cetol: float = 0,
        timePoints: str = NONE,
        fatigue: Boolean = OFF,
        continueAnalysis: Boolean = OFF,
        minCycleInc: int = 100,
        maxCycleInc: int = 1000,
        maxNumCycles: SymbolicConstant = DEFAULT,
        damageExtrapolationTolerance: float = 1,
        matrixStorage: SymbolicConstant = SOLVER_DEFAULT,
        extrapolation: SymbolicConstant = LINEAR,
        maintainAttributes: Boolean = False,
        convertSDI: SymbolicConstant = PROPAGATED,
    ):
        """This method creates a DirectCyclicStep object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].DirectCyclicStep

        Parameters
        ----------
        name
            A String specifying the repository key.
        previous
            A String specifying the name of the previous step. The new step appears after this step
            in the list of analysis steps.
        description
            A String specifying a description of the new step. The default value is an empty string.
        timePeriod
            A Float specifying the time of single loading cycle. The default value is 1.0.
        timeIncrementationMethod
            A SymbolicConstant specifying the time incrementation method to be used. Possible values
            are FIXED and AUTOMATIC. The default value is AUTOMATIC.
        maxNumInc
            An Int specifying the maximum number of increments in a step. The default value is 100.
        initialInc
            A Float specifying the initial time increment. The default value is the total time
            period for the step.
        minInc
            A Float specifying the minimum time increment allowed. The default value is the smaller
            of the suggested initial time increment or 10−5 times the total time period.
        maxInc
            A Float specifying the maximum time increment allowed. The default value is the total
            time period for the step.
        maxNumIterations
            An Int specifying the maximum number of iterations in a step. The default value is 200.
        initialTerms
            An Int specifying the initial number of terms in the Fourier series. The default value
            is 11.
        maxTerms
            An Int specifying the maximum number of terms in the Fourier series. The default value
            is 25.
        termsIncrement
            An Int specifying the increment in number of terms in the Fourier series. The default
            value is 5.
        deltmx
            A Float specifying the maximum temperature change to be allowed in an increment. The
            default value is 0.0.
        cetol
            A Float specifying the maximum difference in the creep strain increment calculated from
            the creep strain rates at the beginning and end of the increment. The default value is
            0.0.
        timePoints
            None or a String specifying a String specifying the name of a time point object used to
            determine at which times the response of the structure will be evaluated. The default
            value is NONE.
        fatigue
            A Boolean specifying whether to include low-cycle fatigue analysis. The default value is
            OFF.
        continueAnalysis
            A Boolean specifying whether the displacement solution in the Fourier series obtained in
            the previous direct cyclic step is used as the starting values for the current step. The
            default value is OFF.
        minCycleInc
            An Int specifying the minimum number of cycles over which the damage is extrapolated
            forward. The default value is 100.
        maxCycleInc
            An Int specifying the maximum number of cycles over which the damage is extrapolated
            forward. The default value is 1000.
        maxNumCycles
            The SymbolicConstant DEFAULT or an Int specifying the maximum number of cycles allowed
            in a step or DEFAULT. A value of 1 plus half of the maximum number of cycles will be
            used if DEFAULT is specified. The default value is DEFAULT.
        damageExtrapolationTolerance
            A Float specifying the maximum extrapolated damage increment. The default value is 1.0.
        matrixStorage
            A SymbolicConstant specifying the type of matrix storage. Possible values are SYMMETRIC,
            UNSYMMETRIC, and SOLVER_DEFAULT. The default value is SOLVER_DEFAULT.
        extrapolation
            A SymbolicConstant specifying the type of extrapolation to use in determining the
            incremental solution for a nonlinear analysis. Possible values are NONE, LINEAR, and
            PARABOLIC. The default value is LINEAR.
        maintainAttributes
            A Boolean specifying whether to retain attributes from an existing step with the same
            name. The default value is False.
        convertSDI
            A SymbolicConstant specifying whether to force a new iteration if severe discontinuities
            occur during an iteration. Possible values are PROPAGATED, CONVERT_SDI_OFF, and
            CONVERT_SDI_ON. The default value is PROPAGATED.

        Returns
        -------
        DirectCyclicStep
            A :py:class:`~abaqus.Step.DirectCyclicStep.DirectCyclicStep` object.

        Raises
        ------
        RangeError
        """
        super().__init__()
        pass

    def setValues(
        self,
        description: str = "",
        timePeriod: float = 1,
        timeIncrementationMethod: SymbolicConstant = AUTOMATIC,
        maxNumInc: int = 100,
        initialInc: float = None,
        minInc: float = None,
        maxInc: float = None,
        maxNumIterations: int = 200,
        initialTerms: int = 11,
        maxTerms: int = 25,
        termsIncrement: int = 5,
        deltmx: float = 0,
        cetol: float = 0,
        timePoints: str = NONE,
        fatigue: Boolean = OFF,
        continueAnalysis: Boolean = OFF,
        minCycleInc: int = 100,
        maxCycleInc: int = 1000,
        maxNumCycles: SymbolicConstant = DEFAULT,
        damageExtrapolationTolerance: float = 1,
        matrixStorage: SymbolicConstant = SOLVER_DEFAULT,
        extrapolation: SymbolicConstant = LINEAR,
        convertSDI: SymbolicConstant = PROPAGATED,
    ):
        """This method modifies the DirectCyclicStep object.

        Parameters
        ----------
        description
            A String specifying a description of the new step. The default value is an empty string.
        timePeriod
            A Float specifying the time of single loading cycle. The default value is 1.0.
        timeIncrementationMethod
            A SymbolicConstant specifying the time incrementation method to be used. Possible values
            are FIXED and AUTOMATIC. The default value is AUTOMATIC.
        maxNumInc
            An Int specifying the maximum number of increments in a step. The default value is 100.
        initialInc
            A Float specifying the initial time increment. The default value is the total time
            period for the step.
        minInc
            A Float specifying the minimum time increment allowed. The default value is the smaller
            of the suggested initial time increment or 10−5 times the total time period.
        maxInc
            A Float specifying the maximum time increment allowed. The default value is the total
            time period for the step.
        maxNumIterations
            An Int specifying the maximum number of iterations in a step. The default value is 200.
        initialTerms
            An Int specifying the initial number of terms in the Fourier series. The default value
            is 11.
        maxTerms
            An Int specifying the maximum number of terms in the Fourier series. The default value
            is 25.
        termsIncrement
            An Int specifying the increment in number of terms in the Fourier series. The default
            value is 5.
        deltmx
            A Float specifying the maximum temperature change to be allowed in an increment. The
            default value is 0.0.
        cetol
            A Float specifying the maximum difference in the creep strain increment calculated from
            the creep strain rates at the beginning and end of the increment. The default value is
            0.0.
        timePoints
            None or a String specifying a String specifying the name of a time point object used to
            determine at which times the response of the structure will be evaluated. The default
            value is NONE.
        fatigue
            A Boolean specifying whether to include low-cycle fatigue analysis. The default value is
            OFF.
        continueAnalysis
            A Boolean specifying whether the displacement solution in the Fourier series obtained in
            the previous direct cyclic step is used as the starting values for the current step. The
            default value is OFF.
        minCycleInc
            An Int specifying the minimum number of cycles over which the damage is extrapolated
            forward. The default value is 100.
        maxCycleInc
            An Int specifying the maximum number of cycles over which the damage is extrapolated
            forward. The default value is 1000.
        maxNumCycles
            The SymbolicConstant DEFAULT or an Int specifying the maximum number of cycles allowed
            in a step or DEFAULT. A value of 1 plus half of the maximum number of cycles will be
            used if DEFAULT is specified. The default value is DEFAULT.
        damageExtrapolationTolerance
            A Float specifying the maximum extrapolated damage increment. The default value is 1.0.
        matrixStorage
            A SymbolicConstant specifying the type of matrix storage. Possible values are SYMMETRIC,
            UNSYMMETRIC, and SOLVER_DEFAULT. The default value is SOLVER_DEFAULT.
        extrapolation
            A SymbolicConstant specifying the type of extrapolation to use in determining the
            incremental solution for a nonlinear analysis. Possible values are NONE, LINEAR, and
            PARABOLIC. The default value is LINEAR.
        convertSDI
            A SymbolicConstant specifying whether to force a new iteration if severe discontinuities
            occur during an iteration. Possible values are PROPAGATED, CONVERT_SDI_OFF, and
            CONVERT_SDI_ON. The default value is PROPAGATED.

        Raises
        ------
        RangeError
        """
        pass
